//
//  MCLRecordingConfig.h
//
//  An online version of the documentation can be found at https://docs.megacool.co
//
//  Do you feel like this reading docs? (╯°□°）╯︵ ┻━┻  Give us a shout if there's anything that's
//  unclear and we'll try to brighten the experience. We can sadly not replace flipped tables.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>

#import "MCLConstants.h"

/**
 Pass this to `-[Megacool startRecording:withConfig:]` to configure how recordings are made.

 @note This class does not have atomic properties for efficiency, thus it's not thread-safe.
 */
@interface MCLRecordingConfig : NSObject <NSCopying>
NS_ASSUME_NONNULL_BEGIN

/**
 How to handle frames when they the total surpasses `maxFrames.`

 The default is `kMCLOverflowStrategyLatest` , which will only keep the most recent
 ones. The alternative is `@"timelapse"`, which will contain frames from the entire
 recording but sped up so that the total is not surpassed. Note that when using
 `@"timelapse"` the total number of frames will be between 1.33* `maxFrames` and 0.67*
 `maxFrames` , such that the *expected* value will be `maxFrames` , but it might sometimes be
 more.
 */
@property(nonatomic) MCLOverflowStrategy overflowStrategy;


/**
  An identifier for this recording, useful when you might have multiple in-progress
 recordings.

 Can be used to retrieve the same recording later, for previews or shares, or to resume
 a paused recording.
 */
@property(nonatomic, null_resettable, strong) NSString *recordingId;


/**
 Max number of frames in a recording.

 Default is 50 frames. What happens when a recording grows above the `maxFrames` limit
 is determined by the overflow strategy, see the documentation for `captureFrame` or
 `startRecording` for details.
 */
@property(nonatomic) int maxFrames;


/**
 Set numbers of frames per second to record.

 Default is 10 frames / second. The GIF will be recorded with this frame rate.
 */
@property(nonatomic) int frameRate;


/**
 Set numbers of frames per second to play.

 Default is 20% more than the capture frame rate. The GIF will be exported with this frame rate.
 */
@property(nonatomic) int playbackFrameRate;


/**
 Percentage of highlight that should occur before maximum number of points is scored

 */
@property(nonatomic) double peakLocation;


/**
 Set a delay (in milliseconds) on the last frame in the animation.

 Default is 1000 (1s). If set to 0 the last frame will have the same duration as the
 rest of the frames, ie. 1/playbackFrameRate.
 */
@property(nonatomic) int lastFrameDelay;


/**
 Set a default custom overlay for the last frame in the animation.

 This can also be set as a URL if you have the image on disk with
 `lastFrameOverlayUrl.`
 */
@property(nonatomic, strong, nullable) UIImage *lastFrameOverlay;


/**
 Set a default custom overlay for the last frame in the animation, by URL.

 Same as `lastFrameOverlay`, but given as URL to a local filesystem path
 instead of `UIImage.`
 */
@property(nonatomic, strong, nullable) NSURL *lastFrameOverlayUrl;

NS_ASSUME_NONNULL_END
@end
